var dbPool = require('../helpers/db-pool.js').pool;

exports.insertNewVisit = function(userId, requestBody, cb) { // visit = {userID:   , patientID:   , answers: [{questionID:   , answerID:  }]}
    dbPool.getConnection(function(err, connection){
        if (err) {
            connection.release();
            cb(err, null);
            throw err;
        }
        var visit = JSON.parse(requestBody.data);
        var patientId = visit.patientId;
        connection.query("INSERT INTO VISIT( UserID, PatientID, DateTime) VALUES (? , ?, NOW())", //insert userid, patientid and datetime into the DB
                            [userId, patientId], (function(err, result) { //define callback to insert answers if insert visit is successful
                if (err) throw err;
                var visitId = result.insertId; //result object gives the ID of the newly inserted visit
                var anslen = this.answers.length; //looks at the number of question/answers to insert
                for (var i=0; i < anslen; i++) { //loop through the answers inserting them into the responses table
                    var answer = this.answers[i]; //get the current question answer
                    connection.query("INSERT INTO RESPONSE( VisitID, QuestionID, AnswerID, Response) VALUES (? , ?, ?, ?)",
                                [visitId, answer.questionId, answer.answerId, answer.response],
                        function (err, result) {
                            if (err) throw err;
                        });
                    }
                connection.release();
            }).bind(visit)
        );
    });
};


exports.getVisitsForPatientID = function(patientID, cb) {
    dbPool.getConnection(function(err, connection){
        if (err) {
            connection.release();
            cb(err, null);
            throw err;
        }
        connection.query("SELECT VISIT.VisitID, VISIT.UserID, VISIT.PatientID, VISIT.DateTime, USER.FirstName, USER.LastName FROM VISIT INNER JOIN USER ON VISIT.UserID = USER.UserID WHERE VISIT.PatientID = ? ORDER BY VISIT.DateTime DESC", patientID , cb);
        connection.release();
    })
};

exports.getVisits = function(userId, cb) {
    dbPool.getConnection(function(err, connection){
        if (err) {
            connection.release();
            cb(err, null);
            throw err;
        }
        connection.query("SELECT VISIT.VisitID, VISIT.UserID, VISIT.PatientID, VISIT.DateTime, PATIENT.FirstName, PATIENT.LastName, USER.FirstName as UserFirstName, USER.LastName as UserLastName\n" +
            "FROM VISIT\n" +
            "INNER JOIN PATIENT ON VISIT.PatientID = PATIENT.PatientID\n" +
            "INNER JOIN ACCESS ON PATIENT.PatientID = ACCESS.PatientID\n" +
            "INNER JOIN USER ON VISIT.UserID = USER.UserID\n" +
            "WHERE ACCESS.Permission = 1\n" +
            "AND USER.UserID = ACCESS.UserID " +
            "AND ACCESS.UserID = ?\n" +
            "ORDER BY VISIT.DateTime DESC", userId, cb);
        connection.release();
    })
};

exports.getResponseForVisit = function(patientid, visitid, cb) {
    dbPool.getConnection(function(err, connection){
        if (err) {
            connection.release();
            cb(err, null);
            throw err;
        }
        connection.query("SELECT RESPONSE.VisitID, RESPONSE.QuestionID, RESPONSE.AnswerID, QUESTION.Question, QUESTION.QuestionType, ANSWER.Answer, VISIT.PatientID, RESPONSE.Response FROM RESPONSE INNER JOIN QUESTION ON RESPONSE.QuestionID = QUESTION.QuestionID LEFT JOIN ANSWER ON RESPONSE.AnswerID = ANSWER.AnswerID INNER JOIN VISIT ON RESPONSE.VisitID = VISIT.VisitID WHERE VISIT.PatientID = ? AND RESPONSE.VisitID = ?", [patientid , visitid], cb);
        connection.release();
    })
};