var express = require('express'); /*include express.js library*/
var router = express.Router(); /*created router using express,js*/
var patientModel = require('../models/patientModel');
var questionModel = require('../models/questionModel');
var visitModel = require('../models/visitModel');
var verifyToken = require('../helpers/verifyToken.js');

//http://localhost:4000/patients to get all patients
//http://localhost:4000/patients/4

router.get('/', verifyToken, function(req, res, next){ /*When GET localhost/users is called, call function with 2 parameters*/
    //Here's a function you need to call on GET /patients
        patientModel.getAllPatients(req.userId, function (err, result) { //created a function called getAll which is stored in userModel.js. The parameter is a function that takes a error and a result
                if (err) throw err; //result is an error
                    res.json(result); //return all users in json format
        });
});

router.get('/:id', verifyToken, function(req, res, next){ /*When GET localhost/carers is called, call function with 3 parameters*/
    //Here's a function you need to call on GET /carers
    patientModel.getOnePatient(req.userId, req.params.id, function (err, result) { //write a query to the DB, and with this data returns either an error or result from query using that data
        if (err) throw err;
        res.json(result); //result in format json
    });
});

router.get('/:id/questions', verifyToken, function(req, res, next){/*When GET localhost/carers is called, call function with 3 parameters*/

    questionModel.getQuestionsByPatient(req.userId, req.params.id, function (err, result) { //write a query to the DB, and with this data returns either an error or result from query using that data
        if (err) throw err;
        var resultLength = result.length;
        var newResult = []; //create a new array
        function Answer(answerID,answer){ //constructor for an object. When I want an object to hold answers
            this.answerID = answerID;
            this.answer = answer;
        }
        function Question(questionID, question, questionType, answer){ //constructor for an object. When I want an object to hold questions
            this.questionID = questionID;
            this.question = question;
            this.questionType = questionType;
            this.answers = [];
            this.answers.push(answer)
        }
        var question = undefined;
        var answer = undefined;
        for(i = 0, currentID = -1; i < resultLength; i++ ){ //currentID is initialized to -1 which won't appear as an ID in the DB
            var quid = result[i].QuestionID; //get question ID
            if (currentID !== quid){ //if the current question id has changed
                answer =  new Answer(result[i].AnswerID, result[i].Answer); //create a new answer object
                question = new Question(quid, result[i].Question, result[i].QuestionType, answer); //create a new question record, containing the new answer
                newResult.push(question); //pushes it into my list questions
                currentID = quid; //set the currentID to the questionID, when go through loop again can check if its the same
            }
            else {
                answer = new Answer(result[i].AnswerID, result[i].Answer); //creating a new answer object
                question.answers.push(answer); //pushing it into the answers for the current question
            }
        }
        res.json(newResult); //result in format json
    });
});

router.post('/', verifyToken, function(req, res, next){
    patientModel.insertNewPatient(req.userId, req.body, function(err, result) {
        if (err) throw err;
        res.json(result);
    });
});

router.get('/:id/visits', verifyToken, function(req, res, next){ /*When GET localhost/carers is called, call function with 3 parameters*/
    //Here's a function you need to call on GET /carers
    visitModel.getVisitsForPatientID(req.params.id, function (err, result) { //write a query to the DB, and with this data returns either an error or result from query using that data
        if (err) throw err;
        res.json(result); //result in format json
    });
});

router.get('/:patientid/visits/:visitid', verifyToken, function(req, res, next){ /*When GET localhost/carers is called, call function with 3 parameters*/
    //Here's a function you need to call on GET /carers
    visitModel.getSpecificVisitForPatientID(req.params.patientid, req.params.visitid, function (err, result) { //write a query to the DB, and with this data returns either an error or result from query using that data
        if (err) throw err;
        res.json(result); //result in format json
    });
});

router.get('/:patientid/visits/:visitid/response', verifyToken, function(req, res, next){ /*When GET localhost/carers is called, call function with 3 parameters*/
    //Here's a function you need to call on GET /carers
    visitModel.getResponseForVisit(req.params.patientid, req.params.visitid, function (err, result) { //write a query to the DB, and with this data returns either an error or result from query using that data
        if (err) throw err;
        res.json(result); //result in format json
    });
});

router.post('/questions', verifyToken, function(req, res, next){
    questionModel.insertQuestionsByUserId(req.userId, req.body, function(err, result) {
        if (err) throw err;
        res.json(result);
    });
});



module.exports = router; //make router visible to the outside world
