var express = require('express'); /*include express.js library*/
var router = express.Router(); /*created router using express,js*/
var usersModel = require('../models/usersModel');
var verifyToken = require('../helpers/verifyToken.js');

//http://localhost:4000/users to get all users
//http://localhost:4000/users?role=family to get all users thats role are family
//http://localhost:4000/users?role=carer to get all users thats role are carers
//http://localhost:4000/users?patientID=3 to get all users with a patient id

router.get('/', verifyToken, function(req, res, next){ /*When GET localhost/users is called, call function with 2 parameters*/
    //Here's a function you need to call on GET /users
    if (req.query.role !== undefined){
        usersModel.getType(req.query.role, function (err, result) { //write a query to the DB, and with this data returns either an error or result from query using that data
            if (err) throw err;
            res.json(result); //result in format json
        });
    }

    else if (req.query.patientID !== undefined ) {
        usersModel.getByPatientID(req.query.patientID, function (err, result) { //write a query to the DB, and with this data returns either an error or result from query using that data
            if (err) throw err;
            res.json(result); //result in format json
        });

    }
    else {
        usersModel.getAll(function (err, result) { //created a function called getAll which is stored in userModel.js. The parameter is a function that takes a error and a result
            if (err) throw err; //result is an error
            res.json(result); //return all users in json format
        });
    }

});

router.get('/me', verifyToken, function(req, res, next){
    res.send("" + req.userId);
});

router.get('/patient', verifyToken, function(req, res, next){
    usersModel.getPatientForFamily(req.userId ,function (err, result) {
        if (err) throw err; //result is an error
        res.json(result);
    })
});

router.post('/group', verifyToken, function(req, res, next){
    usersModel.assignMemberToPatient(req.userId, req.body, function (err, result) {
        if (err) {
            if (err === 404) {
                res.status(err).json(result);
            } else {
                throw err;
            }
        } else {//result is an error
            res.json(result);
        }
    })
});

router.get('/group', verifyToken, function(req, res, next){
    usersModel.getGroupMembers(req.userId, function (err, result) {
        if (err) throw err; //result is an error
        res.json(result);
    })
});

router.put('/permission', verifyToken, function(req, res, next){
    usersModel.updateUserPermission(req.userId, req.body, function (err, result) {
        if (err) throw err; //result is an error
        res.json(result);
    })
});

/* GET specific user REST resource */
//http://localhost:4000/users/1 to get a specific user id
router.get('/:id', verifyToken, function(req, res, next){ /*When GET localhost/carers is called, call function with 3 parameters*/
    //Here's a function you need to call on GET /carers
    usersModel.getOne(req.params.id, function (err, result) { //write a query to the DB, and with this data returns either an error or result from query using that data
        if (err) throw err;
        res.json(result); //result in format json
    });
});

router.post('/', function(req, res){ // no token verification as this is the login
    usersModel.insertNewUser(req.body, function(err, result) {
        if (err) throw err;
        if (result.auth) {
            res.status(201).send(result); //return success
        } else {
            res.status(409).send(result); //return conflict
        }
    });

});

router.post('/login', function (req, res) { // no token verification as this is the login
    var data = req.body;
    usersModel.login(data, function(err, result) {
        if (err) throw err;
        if (result.auth) {
            res.status(201).send(result); //return success
        } else {
            res.status(401).send(result); //return unauthorized
        }
    });
});


module.exports = router; //make router visible to the outside world
